==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/types/update_channel.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class UpdateChannel(Object):
    """Attributes:
        ID: ``0xb6d45656``

    Parameters:
        channel_id: ``int`` ``32-bit``
    """

    __slots__ = ["channel_id"]

    ID = 0xb6d45656
    QUALNAME = "types.UpdateChannel"

    def __init__(self, *, channel_id: int):
        self.channel_id = channel_id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "UpdateChannel":
        # No flags
        
        channel_id = Int.read(b)
        
        return UpdateChannel(channel_id=channel_id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.channel_id))
        
        return b.getvalue()

==> Pyrogram-0.15.1-py3-none-any.whl: pyrogram/api/types/update_channel.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class UpdateChannel(TLObject):
    """Attributes:
        LAYER: ``102``

    Attributes:
        ID: ``0xb6d45656``

    Parameters:
        channel_id: ``int`` ``32-bit``
    """

    __slots__ = ["channel_id"]

    ID = 0xb6d45656
    QUALNAME = "types.UpdateChannel"

    def __init__(self, *, channel_id: int):
        self.channel_id = channel_id  # int

    @staticmethod
    def read(b: BytesIO, *args) -> "UpdateChannel":
        # No flags
        
        channel_id = Int.read(b)
        
        return UpdateChannel(channel_id=channel_id)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Int(self.channel_id))
        
        return b.getvalue()
